Class: Aws::Firehose::Types::AmazonOpenSearchServerlessBufferingHints

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-firehose/types.rb

Overview

Describes the buffering to perform before delivering data to the Serverless offering for Amazon OpenSearch Service destination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#interval_in_secondsInteger

Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).



34
35
36
37
38
39
# File 'lib/aws-sdk-firehose/types.rb', line 34

class AmazonOpenSearchServerlessBufferingHints < Struct.new(
  :interval_in_seconds,
  :size_in_m_bs)
  SENSITIVE = []
  include Aws::Structure
end

#size_in_m_bsInteger

Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.

We recommend setting this parameter to a value greater than the amount of data you typically ingest into the Firehose stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.



34
35
36
37
38
39
# File 'lib/aws-sdk-firehose/types.rb', line 34

class AmazonOpenSearchServerlessBufferingHints < Struct.new(
  :interval_in_seconds,
  :size_in_m_bs)
  SENSITIVE = []
  include Aws::Structure
end