Method: Aws::Firehose::Types::DeliveryStreamEncryptionConfiguration#failure_description

Defined in:
lib/aws-sdk-firehose/types.rb

#failure_descriptionTypes::FailureDescription

Provides details in case one of the following operations fails due to an error related to KMS: CreateDeliveryStream, DeleteDeliveryStream, StartDeliveryStreamEncryption, StopDeliveryStreamEncryption.



1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-firehose/types.rb', line 1537

class DeliveryStreamEncryptionConfiguration < Struct.new(
  :key_arn,
  :key_type,
  :status,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end