Method: Aws::Firehose::Types::DeliveryStreamEncryptionConfiguration#status

Defined in:
lib/aws-sdk-firehose/types.rb

#statusString

This is the server-side encryption (SSE) status for the Firehose stream. For a full description of the different values of this status, see StartDeliveryStreamEncryption and StopDeliveryStreamEncryption. If this status is ENABLING_FAILED or DISABLING_FAILED, it is the status of the most recent attempt to enable or disable SSE, respectively.

Returns:

  • (String)


1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-firehose/types.rb', line 1537

class DeliveryStreamEncryptionConfiguration < Struct.new(
  :key_arn,
  :key_type,
  :status,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end