Method: Aws::Firehose::Types::SnowflakeDestinationConfiguration#table

Defined in:
lib/aws-sdk-firehose/types.rb

#tableString

All data in Snowflake is stored in database tables, logically structured as collections of columns and rows.



5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
# File 'lib/aws-sdk-firehose/types.rb', line 5011

class SnowflakeDestinationConfiguration < Struct.new(
  :account_url,
  :private_key,
  :key_passphrase,
  :user,
  :database,
  :schema,
  :table,
  :snowflake_role_configuration,
  :data_loading_option,
  :meta_data_column_name,
  :content_column_name,
  :snowflake_vpc_configuration,
  :cloud_watch_logging_options,
  :processing_configuration,
  :role_arn,
  :retry_options,
  :s3_backup_mode,
  :s3_configuration,
  :secrets_manager_configuration,
  :buffering_hints)
  SENSITIVE = [:account_url, :private_key, :key_passphrase, :user, :database, :schema, :table, :meta_data_column_name, :content_column_name]
  include Aws::Structure
end