Method: Aws::Firehose::Types::DatabaseSnapshotInfo#id
- Defined in:
- lib/aws-sdk-firehose/types.rb
#id ⇒ String
The identifier of the current snapshot of the table in source database endpoint.
Amazon Data Firehose is in preview release and is subject to change.
1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-firehose/types.rb', line 1068 class DatabaseSnapshotInfo < Struct.new( :id, :table, :request_timestamp, :requested_by, :status, :failure_description) SENSITIVE = [] include Aws::Structure end |